@@ -12,6 +12,7 @@ local strip, split = lousy.util.string.strip, lousy.util.string.split
 
 -- Globals or defaults that are used in binds
 local scroll_step = globals.scroll_step or 20
+local page_step = globals.page_step or 1.0
 local zoom_step = globals.zoom_step or 0.1
 
 -- Add binds to a mode
@@ -199,30 +200,30 @@ add_binds("normal", {
         function (w) w:scroll{ ypagerel = -0.5 } end),
 
     key({"Control"}, "f", "Scroll page down.",
-        function (w) w:scroll{ ypagerel =  1.0 } end),
+        function (w) w:scroll{ ypagerel =  page_step } end),
 
     key({"Control"}, "b", "Scroll page up.",
-        function (w) w:scroll{ ypagerel = -1.0 } end),
+        function (w) w:scroll{ ypagerel = -page_step } end),
 
     key({}, "space", "Scroll page down.",
-        function (w) w:scroll{ ypagerel =  1.0 } end),
+        function (w) w:scroll{ ypagerel =  page_step } end),
 
     key({"Shift"}, "space", "Scroll page up.",
-        function (w) w:scroll{ ypagerel = -1.0 } end),
+        function (w) w:scroll{ ypagerel = -page_step } end),
 
     key({}, "BackSpace", "Scroll page up.",
-        function (w) w:scroll{ ypagerel = -1.0 } end),
+        function (w) w:scroll{ ypagerel = -page_step } end),
 
     key({}, "Page_Down", "Scroll page down.",
-        function (w) w:scroll{ ypagerel =  1.0 } end),
+        function (w) w:scroll{ ypagerel =  page_step } end),
 
     key({}, "Page_Up", "Scroll page up.",
-        function (w) w:scroll{ ypagerel = -1.0 } end),
+        function (w) w:scroll{ ypagerel = -page_step } end),
 
-    key({}, "Home", "Go to the end of the document.",
+    key({}, "Home", "Go to the top of the document.",
         function (w) w:scroll{ y =  0 } end),
 
-    key({}, "End", "Go to the top of the document.",
+    key({}, "End", "Go to the end of the document.",
         function (w) w:scroll{ y = -1 } end),
 
     -- Specific scroll
@@ -268,7 +269,7 @@ add_binds("normal", {
     key({}, "F11", "Toggle fullscreen mode.",
         function (w) w.win.fullscreen = not w.win.fullscreen end),
 
-    -- Clipboard
+    -- Open primary selection contents.
     buf("^pp$", [[Open a URL based on the current primary selection contents
         in the current tab.]],
         function (w)
@@ -293,6 +294,7 @@ add_binds("normal", {
             window.new{w:search_open(uri)}
         end),
 
+    -- Open clipboard contents.
     buf("^PP$", [[Open a URL based on the current clipboard selection contents
         in the current tab.]],
         function (w)
@@ -311,7 +313,7 @@ add_binds("normal", {
 
     buf("^PW$", [[Open a URL based on the current clipboard selection contents
         in a new window.]],
-        function(w, m)
+        function(w)
             local uri = luakit.selection.clipboard
             if not uri then w:notify("Nothing in clipboard...") return end
             window.new{w:search_open(uri)}
@@ -391,12 +393,6 @@ add_binds("normal", {
     key({"Shift","Control"}, "Tab", "Go to previous tab.",
         function (w) w:prev_tab() end),
 
-    key({}, "J", "Go to next tab (or `[count]` nth next tab).",
-        function (w, m) w:next_tab(m.count) end, {count=1}),
-
-    key({}, "K", "Go to previous tab (or `[count]` nth previous tab).",
-        function (w, m) w:prev_tab(m.count) end, {count=1}),
-
     buf("^gT$", "Go to previous tab.",
         function (w) w:prev_tab() end),
 
@@ -536,6 +532,16 @@ add_cmds({
             end
         end),
 
+    key({"Control"}, "Return",
+        [[Expand `:[tab,win]open example` to `:[tab,win]open www.example.com`.]],
+        function (w)
+            local tokens = split(w.ibar.input.text, "%s+")
+            if string.match(tokens[1], "^:%w*open$") and #tokens == 2 then
+                w:enter_cmd(string.format("%s www.%s.com", tokens[1], tokens[2]))
+            end
+            w:activate()
+        end),
+
     cmd("c[lose]", "Close current tab.",
         function (w) w:close_tab() end),
 
